@@ -2,5 +2,4 @@
 # Copyright 2015 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Universal Chess Interface (UCI).
-"""
+"""Universal Chess Interface (UCI)."""
