@@ -13,83 +13,86 @@ import re
 from copy import deepcopy
 
 
-class EngineError(Exception):
-    pass
-
-
-class CommandsToEngine(object):
+class CommandsToEngine:
     """The names of commands sent to engines."""
-    uci = 'uci'
-    debug = 'debug'
-    isready = 'isready'
-    setoption = 'setoption'
-    register = 'register'
-    ucinewgame = 'ucinewgame'
-    position = 'position'
-    go = 'go'
-    stop = 'stop'
-    ponderhit = 'ponderhit'
-    quit_ = 'quit'
-    start = 'start'
+
+    uci = "uci"
+    debug = "debug"
+    isready = "isready"
+    setoption = "setoption"
+    register = "register"
+    ucinewgame = "ucinewgame"
+    position = "position"
+    go = "go"
+    stop = "stop"
+    ponderhit = "ponderhit"
+    quit_ = "quit"
+    start = "start"
 
 
-class GoSubCommands(object):
+class GoSubCommands:
     """The names of sub-commands of the go command sent to engines."""
-    searchmoves = 'searchmoves'
-    ponder = 'ponder'
-    wtime = 'wtime'
-    btime = 'btime'
-    winc = 'winc'
-    binc = 'binc'
-    movestogo = 'movestogo'
-    depth = 'depth'
-    nodes = 'nodes'
-    mate = 'mate'
-    movetime = 'movetime'
-    infinite = 'infinite'
+
+    searchmoves = "searchmoves"
+    ponder = "ponder"
+    wtime = "wtime"
+    btime = "btime"
+    winc = "winc"
+    binc = "binc"
+    movestogo = "movestogo"
+    depth = "depth"
+    nodes = "nodes"
+    mate = "mate"
+    movetime = "movetime"
+    infinite = "infinite"
 
 
-class PositionSubCommands(object):
+class PositionSubCommands:
     """The names of sub-commands of the position command sent to engines."""
-    fen = 'fen'
-    startpos = 'startpos'
-    moves = 'moves'
+
+    fen = "fen"
+    startpos = "startpos"
+    moves = "moves"
 
 
-class SetoptionSubCommands(object):
+class SetoptionSubCommands:
     """The names of sub-commands of the setoption command sent to engines."""
-    name = 'name'
-    value = 'value'
+
+    name = "name"
+    value = "value"
 
 
-class CommandsFromEngine(object):
+class CommandsFromEngine:
     """The names of commands sent by engines."""
-    id_ = 'id'
-    uciok = 'uciok'
-    readyok = 'readyok'
-    bestmove = 'bestmove'
-    copyprotection = 'copyprotection'
-    registration = 'registration'
-    info = 'info'
-    option = 'option'
 
-    all_ = frozenset((id_,
-                      uciok,
-                      readyok,
-                      bestmove,
-                      copyprotection,
-                      registration,
-                      info,
-                      option))
-    terminators = frozenset((uciok,
-                             readyok,
-                             bestmove,
-                             copyprotection,
-                             registration))
+    id_ = "id"
+    uciok = "uciok"
+    readyok = "readyok"
+    bestmove = "bestmove"
+    copyprotection = "copyprotection"
+    registration = "registration"
+    info = "info"
+    option = "option"
+
+    all_ = frozenset(
+        (
+            id_,
+            uciok,
+            readyok,
+            bestmove,
+            copyprotection,
+            registration,
+            info,
+            option,
+        )
+    )
+    terminators = frozenset(
+        (uciok, readyok, bestmove, copyprotection, registration)
+    )
 
     # Regular expression to parse text from engine for command
     # re = '\s+(name|type|default|min|max|var)\s+'
-    cfere = re.compile('|'.join(all_).join(('(?:\A|\s+)(', ')(?:\s+|\Z)')))
+    cfere = re.compile("|".join(all_).join((r"(?:\A|\s+)(", r")(?:\s+|\Z)")))
 
     @staticmethod
     def parse_command(text):
@@ -113,16 +116,17 @@ class CommandsFromEngine(object):
         return cfesplit[1]
 
 
-class IdParameters(object):
+class IdParameters:
     """The names of parameters in the id command."""
-    name = 'name'
-    author = 'author'
+
+    name = "name"
+    author = "author"
 
     all_ = frozenset((name, author))
 
     # Regular expression to parse option command
     # re = '(?<= )(name|author)\s+'
-    ipre = re.compile('|'.join(all_).join(('(?<= )(', ')\s+')))
+    ipre = re.compile("|".join(all_).join((r"(?<= )(", r")\s+")))
 
     @staticmethod
     def parse_id(text):
@@ -142,14 +146,16 @@ class IdParameters(object):
         if ipsplit[0].split()[-1] != CommandsFromEngine.id_:
             return {}
 
-        o = {}
-        for p, v in [ipsplit[i:i+2] for i in range(1, len(ipsplit), 2)]:
-            o[p] = v
-        return o
+        out = {}
+        for key, value in [
+            ipsplit[i : i + 2] for i in range(1, len(ipsplit), 2)
+        ]:
+            out[key] = value
+        return out
 
 
-class OptionParameters(object):
-    """The names of parameters in the option command.
+class OptionParameters:
+    r"""The names of parameters in the option command.
 
     Quoted from the UCI specification (downloaded 9 August 2015):
 
@@ -177,12 +183,13 @@ class OptionParameters(object):
     The gnuchess and stockfish engines, for example, use this interpretation.
 
     """
-    name = 'name'
-    type_ = 'type'
-    default = 'default'
-    min_ = 'min'
-    max_ = 'max'
-    var = 'var'
+
+    name = "name"
+    type_ = "type"
+    default = "default"
+    min_ = "min"
+    max_ = "max"
+    var = "var"
     all_ = frozenset((name, type_, default, min_, max_, var))
 
     # The multi-value parameters
@@ -190,7 +197,7 @@ class OptionParameters(object):
 
     # Regular expression to parse option command
     # re = '(?<= )(name|type|default|min|max|var)\s+'
-    opre = re.compile('|'.join(all_).join(('(?<= )(', ')\s+')))
+    opre = re.compile("|".join(all_).join((r"(?<= )(", r")\s+")))
 
     @staticmethod
     def parse_option(text):
@@ -204,36 +211,41 @@ class OptionParameters(object):
             return {}
 
         # Verify option command is not ambiguous only.
-        for p in op.name, op.type_, op.default, op.min_, op.max_:
-            if opsplit.count(p) > 1:
+        for item in op.name, op.type_, op.default, op.min_, op.max_:
+            if opsplit.count(item) > 1:
                 return {}
 
-        o = {}
-        for p, v in [opsplit[i:i+2] for i in range(1, len(opsplit), 2)]:
-            if p in op.multi:
-                o.setdefault(p, []).append(v)
+        out = {}
+        for key, value in [
+            opsplit[i : i + 2] for i in range(1, len(opsplit), 2)
+        ]:
+            if key in op.multi:
+                out.setdefault(key, []).append(value)
             else:
-                o[p] = v
-        return o
+                out[key] = value
+        return out
 
 
-class OptionTypes(object):
+class OptionTypes:
     """The values of type and <Type> in the <Type>Option namedtuples."""
-    button = 'button'
-    check = 'check'
-    combo = 'combo'
-    spin = 'spin'
-    string = 'string'
+
+    button = "button"
+    check = "check"
+    combo = "combo"
+    spin = "spin"
+    string = "string"
 
 
-ButtonOption = namedtuple('ButtonOption', ('name', 'type'))
-CheckOption = namedtuple('CheckOption', ('name', 'type', 'default'))
-ComboOption = namedtuple('ComboOption', ('name', 'type', 'default', 'var'))
-SpinOption = namedtuple('SpinOption', ('name', 'type', 'default', 'min', 'max'))
-StringOption = namedtuple('StringOption', ('name', 'type', 'default'))
+ButtonOption = namedtuple("ButtonOption", ("name", "type"))
+CheckOption = namedtuple("CheckOption", ("name", "type", "default"))
+ComboOption = namedtuple("ComboOption", ("name", "type", "default", "var"))
+SpinOption = namedtuple(
+    "SpinOption", ("name", "type", "default", "min", "max")
+)
+StringOption = namedtuple("StringOption", ("name", "type", "default"))
 
 
-class ReservedOptionNames(object):
+class ReservedOptionNames:
     """The names of options defined in UCI specification.
 
     Any names starting 'UCI_' not in type_ are invalid and thus ignored.
@@ -242,29 +254,30 @@ class ReservedOptionNames(object):
     specific.
 
     """
-    _false = 'false'
-    _true = 'true'
-    _check_values = frozenset((_true, _false))
 
-    clear_hash = 'Clear Hash'
-    empty_string = '<empty>'
-    reserved_prefix = 'UCI_'
-    Hash = 'Hash'
-    NalimovPath = 'NalimovPath'
-    NalimovCache = 'NalimovCache'
-    Ponder = 'Ponder'
-    OwnBook = 'OwnBook'
-    MultiPV = 'MultiPV'
-    UCI_ShowCurrLine = 'UCI_ShowCurrLine'
-    UCI_ShowRefutations = 'UCI_ShowRefutations'
-    UCI_LimitStrength = 'UCI_LimitStrength'
-    UCI_Elo = 'UCI_Elo'
-    UCI_AnalyseMode = 'UCI_AnalyseMode'
-    UCI_Opponent = 'UCI_Opponent'
-    UCI_EngineAbout = 'UCI_EngineAbout'
-    UCI_ShredderbasesPath = 'UCI_ShredderbasesPath'
-    UCI_SetPositionValue = 'UCI_SetPositionValue'
-    UCI_Chess960 = 'UCI_Chess960'
+    _false = "false"
+    _true = "true"
+    check_values = frozenset((_true, _false))
+
+    clear_hash = "Clear Hash"
+    empty_string = "<empty>"
+    reserved_prefix = "UCI_"
+    Hash = "Hash"
+    NalimovPath = "NalimovPath"
+    NalimovCache = "NalimovCache"
+    Ponder = "Ponder"
+    OwnBook = "OwnBook"
+    MultiPV = "MultiPV"
+    UCI_ShowCurrLine = "UCI_ShowCurrLine"
+    UCI_ShowRefutations = "UCI_ShowRefutations"
+    UCI_LimitStrength = "UCI_LimitStrength"
+    UCI_Elo = "UCI_Elo"
+    UCI_AnalyseMode = "UCI_AnalyseMode"
+    UCI_Opponent = "UCI_Opponent"
+    UCI_EngineAbout = "UCI_EngineAbout"
+    UCI_ShredderbasesPath = "UCI_ShredderbasesPath"
+    UCI_SetPositionValue = "UCI_SetPositionValue"
+    UCI_Chess960 = "UCI_Chess960"
     type_ = {
         Hash: OptionTypes.spin,
         NalimovPath: OptionTypes.string,
@@ -282,17 +295,18 @@ class ReservedOptionNames(object):
         UCI_ShredderbasesPath: OptionTypes.string,
         UCI_SetPositionValue: OptionTypes.string,
         UCI_Chess960: OptionTypes.check,
-        }
+    }
     default = {
-        MultiPV: '1',
+        MultiPV: "1",
         UCI_ShowCurrLine: _false,
         UCI_ShowRefutations: _false,
         UCI_LimitStrength: _false,
-        }
+    }
 
     @staticmethod
     def is_invalid_defined_option(
-        name=None, type_=None, default=None, min_=None, max_=None, var=None):
+        name=None, type_=None, default=None, min_=None, max_=None, var=None
+    ):
         """Return True if arguments are an invalid for a UCI defined option."""
         ron = ReservedOptionNames
         if name not in ron.type_:
@@ -306,7 +320,9 @@ class ReservedOptionNames(object):
         return False
 
 
-def option(name=None, type_=None, default=None, min_=None, max_=None, var=None):
+def option(
+    name=None, type_=None, default=None, min_=None, max_=None, var=None
+):
     """Return a <Type>Option instance for type_, or None if arguments invalid.
 
     UCI usually just ignores invalid options, so do the same here.
@@ -314,42 +330,47 @@ def option(name=None, type_=None, default=None, min_=None, max_=None, var=None):
     """
     if not isinstance(name, str):
         return None
-    if ReservedOptionNames.isinvalid_defined_option(
-        name=name, type_=type_, default=default, min_=min_, max_=max_, var=var):
+    if ReservedOptionNames.is_invalid_defined_option(
+        name=name, type_=type_, default=default, min_=min_, max_=max_, var=var
+    ):
         return None
     if type_ == OptionTypes.button:
         return CheckOption(name=name, type=OptionTypes.button)
-    elif type_ == OptionTypes.check:
-        if not default in _check_values:
+    if type_ == OptionTypes.check:
+        if not default in ReservedOptionNames.check_values:
             return None
         return ButtonOption(name=name, type=OptionTypes.check, default=default)
-    elif type_ == OptionTypes.combo:
+    if type_ == OptionTypes.combo:
         if not isinstance(default, str):
             return None
-        for v in var:
-            if not isinstance(v, str):
+        for item in var:
+            if not isinstance(item, str):
                 return None
         return ComboOption(
-            name=name, type=OptionTypes.combo, default=default, var=tuple(var))
-    elif type_ == OptionTypes.spin:
-        for a in default, min_, max_:
-            if not a.isdigit():
+            name=name, type=OptionTypes.combo, default=default, var=tuple(var)
+        )
+    if type_ == OptionTypes.spin:
+        for spin in default, min_, max_:
+            if not spin.isdigit():
                 return None
         return SpinOption(
             name=name,
             type=OptionTypes.spin,
             default=default,
             min=min_,
-            max=max_)
-    elif type_ == OptionTypes.string:
+            max=max_,
+        )
+    if type_ == OptionTypes.string:
         if not isinstance(default, str):
             return None
-        return StringOption(name=name, type=OptionTypes.string, default=default)
+        return StringOption(
+            name=name, type=OptionTypes.string, default=default
+        )
     return None
 
 
-class InfoParameters(object):
-    """The names of parameters in the info command.
+class InfoParameters:
+    r"""The names of parameters in the info command.
 
     Quoted from the UCI specification (downloaded 9 August 2015):
 
@@ -437,47 +458,51 @@ class InfoParameters(object):
     the info commands adjacent.
 
     """
-    depth = 'depth'
-    seldepth = 'seldepth'
-    time = 'time'
-    nodes = 'nodes'
-    pv = 'pv'
-    multipv = 'multipv'
-    score = 'score'
-    currmove = 'currmove'
-    currmovenumber = 'currmovenumber'
-    hashfull = 'hashfull'
-    nps = 'nps'
-    tbhits = 'tbhits'
-    sbhits = 'sbhits'
-    cpuload = 'cpuload'
-    string = 'string'
-    refutation = 'refutation'
-    currline = 'currline'
 
-    all_ = frozenset((depth,
-                      seldepth,
-                      time,
-                      nodes,
-                      pv,
-                      multipv,
-                      score,
-                      currmove,
-                      currmovenumber,
-                      hashfull,
-                      nps,
-                      tbhits,
-                      sbhits,
-                      cpuload,
-                      string,
-                      refutation,
-                      currline,
-                      ))
+    depth = "depth"
+    seldepth = "seldepth"
+    time = "time"
+    nodes = "nodes"
+    pv = "pv"
+    multipv = "multipv"
+    score = "score"
+    currmove = "currmove"
+    currmovenumber = "currmovenumber"
+    hashfull = "hashfull"
+    nps = "nps"
+    tbhits = "tbhits"
+    sbhits = "sbhits"
+    cpuload = "cpuload"
+    string = "string"
+    refutation = "refutation"
+    currline = "currline"
+
+    all_ = frozenset(
+        (
+            depth,
+            seldepth,
+            time,
+            nodes,
+            pv,
+            multipv,
+            score,
+            currmove,
+            currmovenumber,
+            hashfull,
+            nps,
+            tbhits,
+            sbhits,
+            cpuload,
+            string,
+            refutation,
+            currline,
+        )
+    )
     moves = frozenset((pv, refutation))
 
     # Regular expression to parse info command
     # re = '(?<= )(depth|seldepth|time| ,,, |string|refutation|currline)\s+'
-    ipre = re.compile('|'.join(all_).join(('(?<= )(', ')\s+')))
+    ipre = re.compile("|".join(all_).join((r"(?<= )(", r")\s+")))
 
     @staticmethod
     def parse_info(text):
@@ -493,33 +518,37 @@ class InfoParameters(object):
         # The 'string' info escapes the rest of the line.
         if ip.string in ipsplit:
             i = ipsplit.index(ip.string)
-            ipsplit[i+1:] = [' '.join(ipsplit[i+1:])]
+            ipsplit[i + 1 :] = [" ".join(ipsplit[i + 1 :])]
 
         # Verify info command is not ambiguous only.
         for i in ip.all_:
             if ipsplit.count(i) > 1:
                 return {}
 
-        o = {}
-        for p, v in [ipsplit[i:i+2] for i in range(1, len(ipsplit), 2)]:
-            if p in ip.moves:
-                o.setdefault(p, []).append(v)
-            elif p == ip.currline:
-                o[p] = current_line(v)
-            elif p == ip.score:
-                o[p] = ScoreInfoValueNames.parse_score_info(
-                    ' '.join((ip.score, v)))
+        out = {}
+        for key, value in [
+            ipsplit[i : i + 2] for i in range(1, len(ipsplit), 2)
+        ]:
+            if key in ip.moves:
+                out.setdefault(key, []).append(value)
+            elif key == ip.currline:
+                out[key] = _current_line(value)
+            elif key == ip.score:
+                out[key] = ScoreInfoValueNames.parse_score_info(
+                    " ".join((ip.score, value))
+                )
             else:
-                o[p] = v
-        return o
+                out[key] = value
+        return out
 
 
-class ScoreInfoValueNames(object):
+class ScoreInfoValueNames:
     """The names of score info values and type of value if any."""
-    cp = 'cp'
-    mate = 'mate'
-    lowerbound = 'lowerbound'
-    upperbound = 'upperbound'
+
+    cp = "cp"
+    mate = "mate"
+    lowerbound = "lowerbound"
+    upperbound = "upperbound"
 
     all_ = frozenset((cp, mate, lowerbound, upperbound))
     values = frozenset((cp, mate))
@@ -527,96 +556,101 @@ class ScoreInfoValueNames(object):
 
     # Regular expression to parse score info value
     # re = '(?<= )(cp|mate|lowerbound|upperbound)\s+'
-    sivnre = re.compile('|'.join(all_).join(('(?<= )(', ')\s+')))
+    sivnre = re.compile("|".join(all_).join((r"(?<= )(", r")\s+")))
 
     @staticmethod
     def parse_score_info(text):
         """Recturn dict of score info values extracted from text."""
         sivn = ScoreInfoValueNames
         sivnsplit = [t.strip() for t in sivn.sivnre.split(text)]
-        o = {}
+        out = {}
 
         # Extract lower and upper bound flags and verify not duplicated.
         # 'cp lowerbound' and so forth are not allowed.
         # Apply sivnre to text with flags removed.
         if sivn.flags.intersection(sivnsplit):
             words = text.split()
-            for f in sivn.flags:
-                if f in words:
-                    if words.count(f) > 1:
+            for flag in sivn.flags:
+                if flag in words:
+                    if words.count(flag) > 1:
                         return {}
-                    i = words.index(f)
-                    if words[i-1] in sivn.values:
+                    index = words.index(flag)
+                    if words[index - 1] in sivn.values:
                         return {}
-                    if i != len(words) - 1:
-                        if words[i+1] not in sivn.all_:
+                    if index != len(words) - 1:
+                        if words[index + 1] not in sivn.all_:
                             return {}
-            for f in sivn.flags:
-                words.remove(f)
-            sivnsplit = [t.strip() for t in sivn.sivnre.split(' '.join(words))]
+            for flag in sivn.flags:
+                words.remove(flag)
+            sivnsplit = [t.strip() for t in sivn.sivnre.split(" ".join(words))]
 
         # 'score cp <n> mate <m>' without <junk> is fine.
         if sivnsplit[0] != InfoParameters.score:
             return {}
 
         # Verify score info, cp and mate, is not ambiguous only.
-        for s in sivn.values:
-            if sivnsplit.count(s) > 1:
+        for item in sivn.values:
+            if sivnsplit.count(item) > 1:
                 return {}
 
-        for p, v in [sivnsplit[i:i+2] for i in range(1, len(sivnsplit), 2)]:
-            if p in sivn.values:
-                o[p] = v
+        for key, value in [
+            sivnsplit[i : i + 2] for i in range(1, len(sivnsplit), 2)
+        ]:
+            if key in sivn.values:
+                out[key] = value
             else:
                 return {}
-        return o
+        return out
 
 
-def current_line(text):
+def _current_line(text):
     """Return a ( <cpu number>, ( <move1>, ... ) ) tuple from text.
 
     If the first word of text is digits it is the CPU number.  Otherwise set
     the CPU number to None.
 
     """
-    t = text.split(maxsplit=1)
-    if t[0].isdigit():
-        return t[0], ' '.join(t[1:])
-    else:
-        return None, text
+    line = text.split(maxsplit=1)
+    if line[0].isdigit():
+        return line[0], " ".join(line[1:])
+    return None, text
 
 
-InfoSnapshot = namedtuple('InfoSnapshot',
-                          (InfoParameters.depth,
-                           InfoParameters.seldepth,
-                           InfoParameters.time,
-                           InfoParameters.nodes,
-                           InfoParameters.pv,
-                           InfoParameters.multipv,
-                           InfoParameters.score,
-                           InfoParameters.currmove,
-                           InfoParameters.currmovenumber,
-                           InfoParameters.hashfull,
-                           InfoParameters.nps,
-                           InfoParameters.tbhits,
-                           InfoParameters.sbhits,
-                           InfoParameters.cpuload,
-                           InfoParameters.string,
-                           InfoParameters.refutation,
-                           InfoParameters.currline,
-                           'pv_group',
-                           ))
+InfoSnapshot = namedtuple(
+    "InfoSnapshot",
+    (
+        InfoParameters.depth,
+        InfoParameters.seldepth,
+        InfoParameters.time,
+        InfoParameters.nodes,
+        InfoParameters.pv,
+        InfoParameters.multipv,
+        InfoParameters.score,
+        InfoParameters.currmove,
+        InfoParameters.currmovenumber,
+        InfoParameters.hashfull,
+        InfoParameters.nps,
+        InfoParameters.tbhits,
+        InfoParameters.sbhits,
+        InfoParameters.cpuload,
+        InfoParameters.string,
+        InfoParameters.refutation,
+        InfoParameters.currline,
+        "pv_group",
+    ),
+)
 
 
-class BestmoveParameters(object):
+class BestmoveParameters:
     """The names of parameters in the bestmove command."""
-    ponder = 'ponder'
+
+    ponder = "ponder"
 
     all_ = frozenset((ponder,))
 
     # Regular expression to parse option command
     # re = '(?<= )(ponder)\s+'
-    bpre = re.compile('|'.join(all_).join(('(?<= )(', ')\s+')))
+    bpre = re.compile("|".join(all_).join((r"(?<= )(", r")\s+")))
 
     @staticmethod
     def parse_bestmove(text):
@@ -629,25 +663,27 @@ class BestmoveParameters(object):
         # 'bestmove <move>' or
         # 'bestmove <move> ponder <move>' or
         # are fine but <junk> any where after 'bestmove' is not.
-        
-        bm = bpsplit[0].split()
-        if len(bm) != 2:
+
+        bms = bpsplit[0].split()
+        if len(bms) != 2:
             return {}
-        if bm[0] != CommandsFromEngine.bestmove:
+        if bms[0] != CommandsFromEngine.bestmove:
             return {}
-        o = dict((bm,))
+        out = dict((bms,))
 
         # Verify bestmove is not ambiguous only.
-        for s in bp.all_:
-            if bpsplit.count(s) > 1:
+        for item in bp.all_:
+            if bpsplit.count(item) > 1:
                 return {}
 
-        for p, v in [bpsplit[i:i+2] for i in range(1, len(bpsplit), 2)]:
-            o[p] = v
-        return o
+        for key, value in [
+            bpsplit[i : i + 2] for i in range(1, len(bpsplit), 2)
+        ]:
+            out[key] = value
+        return out
 
 
-class Engine(object):
+class Engine:
     """The chess engine state according to commands from engine.
 
     Info commands from a chess engine are kept in the info attribute: a deque
@@ -662,7 +698,10 @@ class Engine(object):
     created between consecutive bestmove commands from a chess engine.
 
     """
-    _empty_infosnapshot = InfoSnapshot(*[None]*(len(InfoParameters.all_) + 1))
+
+    _empty_infosnapshot = InfoSnapshot(
+        *[None] * (len(InfoParameters.all_) + 1)
+    )
 
     def __init__(self):
         """Create a database state instance."""
@@ -706,59 +745,60 @@ class Engine(object):
         pruning is done before the next 'go' command.
 
         """
-        bp = BestmoveParameters
-        bestmove = bp.parse_bestmove(text)
+        bps = BestmoveParameters
+        bestmove = bps.parse_bestmove(text)
         if bestmove:
             self.bestmove = (text, bestmove)
 
     def note_engine_id(self, text):
-        """"""
-        ip = IdParameters
-        id_ = ip.parse_id(text)
-        for k, v in id_.items():
-            if k in ip.all_:
+        """Note the engine identity extracted from text."""
+        ips = IdParameters
+        id_ = ips.parse_id(text)
+        for k, value in id_.items():
+            if k in ips.all_:
                 if hasattr(self, k):
-                    setattr(self, k, v)
+                    setattr(self, k, value)
 
     def note_engine_info(self, text):
-        """"""
-        ip = InfoParameters
-        info = ip.parse_info(text)
+        """Note the info (analysis) extracted from text."""
+        ips = InfoParameters
+        info = ips.parse_info(text)
         if info:
-            if ip.pv in info:
+            if ips.pv in info:
 
                 # Not simply:
-                #pv_group = self.snapshot.pv_group
-                #pv_group[info.get(ip.multipv)] = info
-                #self.snapshot = self.snapshot._replace(**info)
+                # pv_group = self.snapshot.pv_group
+                # pv_group[info.get(ip.multipv)] = info
+                # self.snapshot = self.snapshot._replace(**info)
                 # because the UCI specification says 'should' not 'must' about
                 # grouping and order of infos.  Retain the depth history of
                 # each line in case there is doubt which could be resolved.
                 pv_group = self.snapshot.pv_group
                 if pv_group is None:
                     pv_group = dict()
-                depth = info.get(ip.depth)
+                depth = info.get(ips.depth)
                 if depth is not None:
                     if depth != self.snapshot.depth:
                         if pv_group is self.snapshot.pv_group:
                             pv_group = deepcopy(self.snapshot.pv_group)
-                pv_group[info.get(ip.multipv)] = info
+                pv_group[info.get(ips.multipv)] = info
                 self.snapshot = self.snapshot._replace(
-                    pv_group=pv_group, **info)
+                    pv_group=pv_group, **info
+                )
 
             else:
                 self.snapshot = self.snapshot._replace(**info)
             self.info.append((text, self.snapshot))
 
     def note_engine_option(self, text):
-        """"""
-        op = OptionParameters
-        option = op.parse_option(text)
-        if option:
-            self.options[option[op.name]] = (text, option)
+        """Note the engine option extracted from text."""
+        ops = OptionParameters
+        engine_option = ops.parse_option(text)
+        if engine_option:
+            self.options[engine_option[ops.name]] = (text, engine_option)
 
     def note_engine_command(self, text):
-        """"""
+        """Note the value for the command returned from engine in test."""
         cfe = CommandsFromEngine
         command = cfe.parse_command(text)
         if command == cfe.info:
@@ -771,15 +811,15 @@ class Engine(object):
             self.note_engine_id(text)
 
     def process_engine_response(self, response):
-        """"""
+        """Process engine commands in response if result code is true."""
         for command_to_engine, result_code, engine_commands in response:
             if result_code:
                 self.process_engine_commands(engine_commands)
 
     def process_engine_commands(self, commands):
-        """"""
-        n, c = commands
-        for i in c:
+        """Note the values in commands from engine."""
+        # n, c = commands
+        for i in commands[1]:
             self.note_engine_command(i)
 
     def initialize_info_snapshot(self):
@@ -788,46 +828,46 @@ class Engine(object):
         self.clear_snapshot()
 
     def clear_snapshot(self):
-        """"""
+        """Clear snapshot and bestmove."""
         self.snapshot = self._empty_infosnapshot._replace(pv_group={})
         self.bestmove = None
 
     @property
     def readyok_expected(self):
-        """"""
+        """Return readyok_expected."""
         return self._readyok_expected
 
     @readyok_expected.setter
     def readyok_expected(self, value):
-        """"""
+        """Set readyok_expected to value: True or False."""
         self._readyok_expected = bool(value)
 
     @property
     def uciok_expected(self):
-        """"""
+        """Return uciok_expected."""
         return self._uciok_expected
 
     @uciok_expected.setter
     def uciok_expected(self, value):
-        """"""
+        """Set uciok_expected to value: True or False."""
         self._uciok_expected = bool(value)
 
     def set_copyprotection(self, status):
-        """"""
-        if status in ('ok', 'checking'):
+        """Set copyprotection to status: 'ok' or 'checking'."""
+        if status in ("ok", "checking"):
             self.copyprotection = status
         else:
-            self.copyprotection = 'error'
+            self.copyprotection = "error"
 
     def set_registration(self, status):
-        """"""
-        if status in ('ok', 'checking', False):
+        """Set registration to status: 'ok', 'checking', or False."""
+        if status in ("ok", "checking", False):
             self.registration = status
         else:
-            self.registration = 'error'
+            self.registration = "error"
 
 
 EngineInterface = namedtuple(
-    'EngineInterface',
-    ['driver', 'program_file_name', 'to_driver_queue', 'parser'],
-    )
+    "EngineInterface",
+    ["driver", "program_file_name", "to_driver_queue", "parser"],
+)
